@@ -6,7 +6,8 @@
 
 #include "config-kaichat.h"
 #include "kaichatcommandlineparser.h"
-#include "kaichatglobalconfig.h"
+#include "textautogeneratetext/textautogeneratetextglobalconfig.h"
+
 #include "kaichatmainwindow.h"
 #include "kaichatutils.h"
 #include <KConfigGroup>
@@ -15,6 +16,8 @@
 #include <QApplication>
 #include <QCommandLineParser>
 #include <TextAutoGenerateText/TextAutoGenerateManager>
+#include <TextAutoGenerateText/TextAutoGeneratePluginTextManager>
+#include <TextAutoGenerateText/TextAutoGenerateTextToolPluginManager>
 #include <TextAutoGenerateText/TextAutoGenerateTextUtils>
 #include <iostream>
 
@@ -35,7 +38,7 @@
 #include <QJsonObject>
 #include <QWindow>
 #include <kdsingleapplication.h>
-#if !defined(Q_OS_WIN) && !defined(Q_OS_MACOS)
+#if !defined(Q_OS_WIN) && !defined(Q_OS_MACOS) && !defined(Q_OS_HAIKU)
 #include <private/qtx11extras_p.h>
 #endif
 #endif
@@ -95,7 +98,7 @@ int main(int argc, char *argv[])
     }
 
     if (parser.isSet(commandLineParser.optionParserFromEnum(KAIChatCommandLineParser::OptionParser::ListChats))) {
-        TextAutoGenerateText::TextAutoGenerateManager manager;
+        const TextAutoGenerateText::TextAutoGenerateManager manager;
         const QStringList lst = manager.chatsList();
         std::cout << qPrintable(i18n("List of Chats:")) << '\n';
         for (const QString &chatTitle : lst) {
@@ -109,8 +112,15 @@ int main(int argc, char *argv[])
         return 0;
     }
 
-    if (KAIChatGlobalConfig::self()->useCustomFont()) {
-        qApp->setFont(KAIChatGlobalConfig::self()->generalFont());
+    if (parser.isSet(KAIChatCommandLineParser::optionParserFromEnum(KAIChatCommandLineParser::OptionParser::PluginInfo))) {
+        std::cout << qPrintable(i18n("Plugins:")) << '\n';
+        std::cout << qPrintable(TextAutoGenerateText::TextAutoGeneratePluginTextManager::self()->generatePluginsInformation()) << '\n';
+        std::cout << qPrintable(TextAutoGenerateText::TextAutoGenerateTextToolPluginManager::self()->generatePluginsInformation()) << '\n';
+        return 0;
+    }
+
+    if (TextAutoGenerateText::TextAutogenerateTextGlobalConfig::self()->useCustomFont()) {
+        qApp->setFont(TextAutoGenerateText::TextAutogenerateTextGlobalConfig::self()->generalFont());
     }
 
 #if WITH_DBUS
@@ -122,7 +132,7 @@ int main(int argc, char *argv[])
         QJsonObject obj;
         obj[QLatin1String("working_dir")] = QDir::currentPath();
         obj[QLatin1String("args")] = QJsonArray::fromStringList(app.arguments());
-#if !defined(Q_OS_WIN) && !defined(Q_OS_MACOS)
+#if !defined(Q_OS_WIN) && !defined(Q_OS_MACOS) && !defined(Q_OS_HAIKU)
         if (KWindowSystem::isPlatformWayland()) {
             obj[QLatin1String("xdg_activation_token")] = qEnvironmentVariable("XDG_ACTIVATION_TOKEN");
         } else if (KWindowSystem::isPlatformX11()) {
@@ -144,7 +154,7 @@ int main(int argc, char *argv[])
         QJsonDocument doc = QJsonDocument::fromJson(messageData);
         QJsonObject message = doc.object();
 
-#if !defined(Q_OS_WIN) && !defined(Q_OS_MACOS)
+#if !defined(Q_OS_WIN) && !defined(Q_OS_MACOS) && !defined(Q_OS_HAIKU)
         if (KWindowSystem::isPlatformWayland()) {
             qputenv("XDG_ACTIVATION_TOKEN", message[QLatin1String("xdg_activation_token")].toString().toUtf8());
         } else if (KWindowSystem::isPlatformX11()) {
