@@ -20,6 +20,10 @@ public:
         SwitchToChatFromId,
         AskMessage,
         ListChats,
+        Debug,
+        Attach,
+        ToolName,
+        PluginInfo,
     };
     explicit KAIChatCommandLineParser(QCommandLineParser *parser);
     ~KAIChatCommandLineParser();
