@@ -20,6 +20,8 @@ public:
 
     void showConfigureDialog(QWidget *parent) override;
 
-    void
-    callTools(const QByteArray &chatId, const QByteArray &uuid, const QList<TextAutoGenerateText::TextAutoGenerateReply::ToolCallArgumentInfo> &info) override;
+    [[nodiscard]] TextAutoGenerateText::TextAutoGenerateTextToolPluginJob *callTool() override;
+    [[nodiscard]] QString iconName() const override;
+
+    [[nodiscard]] int order() const override;
 };
