@@ -5,7 +5,6 @@
 */
 
 #include "currentdatetimetoolpluginjob.h"
-#include "config-kaichat.h"
 #include "currentdatetimetoolpluginutils.h"
 #include "kaichat_currentdatetimeplugin_debug.h"
 #include <KLocalizedString>
@@ -27,13 +26,14 @@ void CurrentDateTimeToolPluginJob::start()
         deleteLater();
         return;
     }
+    Q_EMIT toolInProgress(i18n("Get Current Date Time."));
     QString result;
     const QStringList lst = requiredArguments();
     for (const auto &arg : lst) {
         for (const auto &resultTool : std::as_const(mToolArguments)) {
             if (resultTool.keyTool == arg) {
                 const QString value = resultTool.value;
-                if (arg == "currentdatetime"_L1) {
+                if (arg == CurrentDateTimeToolPluginUtils::currentDateTimePropertyName()) {
                     const CurrentDateTimeToolPluginUtils::DateTimeEnum typeDateTime = CurrentDateTimeToolPluginUtils::convertStringToDateTimeEnum(value);
                     switch (typeDateTime) {
                     case CurrentDateTimeToolPluginUtils::DateTimeEnum::Time:
@@ -55,7 +55,6 @@ void CurrentDateTimeToolPluginJob::start()
     }
 
     qDebug() << " toolArguments " << toolArguments();
-#if HAVE_NEW_ASK_API
     const TextAutoGenerateText::TextAutoGenerateTextToolPlugin::TextToolPluginInfo info{
         .content = result,
         .messageUuid = mMessageUuid,
@@ -63,11 +62,7 @@ void CurrentDateTimeToolPluginJob::start()
         .toolIdentifier = mToolIdentifier,
         .attachementInfoList = {},
     };
-
     Q_EMIT finished(info);
-#else
-    Q_EMIT finished(result, mMessageUuid, mChatId, mToolIdentifier);
-#endif
     deleteLater();
 }
 
