@@ -7,10 +7,10 @@
 #include "kaichatcentralwidget.h"
 #include "config-kaichat.h"
 #include "kaichatglobalconfig.h"
-#include "needupdateversion/needupdateversionwidget.h"
-#include "whatsnew/whatsnewmessagewidget.h"
-#include "whatsnew/whatsnewtranslations.h"
+#include "kaichatwhatsnewtranslations.h"
 #include <QVBoxLayout>
+#include <TextAddonsWidgets/NeedUpdateVersionWidget>
+#include <TextAddonsWidgets/WhatsNewMessageWidget>
 #include <TextAutoGenerateText/TextAutoGenerateChatsModel>
 #include <TextAutoGenerateText/TextAutoGenerateManager>
 #include <TextAutoGenerateText/TextAutoGenerateMessagesModel>
@@ -26,14 +26,15 @@ KAIChatCentralWidget::KAIChatCentralWidget(TextAutoGenerateText::TextAutoGenerat
     mainLayout->setContentsMargins({});
     mainLayout->setSpacing(0);
 
-    WhatsNewTranslations translations;
+    KAIChatWhatsNewTranslations translations;
     const QString newFeaturesMD5 = translations.newFeaturesMD5();
     if (!newFeaturesMD5.isEmpty()) {
         const QString previousNewFeaturesMD5 = KAIChatGlobalConfig::self()->previousNewFeaturesMD5();
         if (!previousNewFeaturesMD5.isEmpty()) {
             const bool hasNewFeature = (previousNewFeaturesMD5 != newFeaturesMD5);
             if (hasNewFeature) {
-                auto whatsNewMessageWidget = new WhatsNewMessageWidget(this);
+                auto whatsNewMessageWidget = new TextAddonsWidgets::WhatsNewMessageWidget(this);
+                whatsNewMessageWidget->setWhatsNewInfos(translations.createWhatsNewInfo());
                 whatsNewMessageWidget->setObjectName(u"whatsNewMessageWidget"_s);
                 mainLayout->addWidget(whatsNewMessageWidget);
                 KAIChatGlobalConfig::self()->setPreviousNewFeaturesMD5(newFeaturesMD5);
@@ -47,10 +48,10 @@ KAIChatCentralWidget::KAIChatCentralWidget(TextAutoGenerateText::TextAutoGenerat
     mTextAutogenerateWidget->setObjectName("mTextAutogenerateWidget"_L1);
     mainLayout->addWidget(mTextAutogenerateWidget);
 
-    if (NeedUpdateVersionUtils::checkVersion()) {
-        const auto status = NeedUpdateVersionUtils::obsoleteVersionStatus(QLatin1StringView(KAICHAT_RELEASE_VERSION), QDate::currentDate());
-        if (status != NeedUpdateVersionUtils::ObsoleteVersion::NotObsoleteYet) {
-            auto needUpdateVersionWidget = new NeedUpdateVersionWidget(this);
+    if (TextAddonsWidgets::NeedUpdateVersionUtils::checkVersion()) {
+        const auto status = TextAddonsWidgets::NeedUpdateVersionUtils::obsoleteVersionStatus(QStringLiteral(KAICHAT_RELEASE_VERSION), QDate::currentDate());
+        if (status != TextAddonsWidgets::NeedUpdateVersionUtils::ObsoleteVersion::NotObsoleteYet) {
+            auto needUpdateVersionWidget = new TextAddonsWidgets::NeedUpdateVersionWidget(this);
             needUpdateVersionWidget->setObjectName(u"needUpdateVersionWidget"_s);
             mainLayout->insertWidget(0, needUpdateVersionWidget);
             needUpdateVersionWidget->setObsoleteVersion(status);
