@@ -17,7 +17,10 @@ class KAIChatChangeFontSizeMenu;
 class QCommandLineParser;
 class QLabel;
 #if defined(Q_OS_WIN) || defined(Q_OS_MACOS)
-class VerifyNewVersionWidgetAction;
+namespace TextAddonsWidgets
+{
+class VerifyNewVersionWidget;
+}
 #endif
 namespace TextAutoGenerateText
 {
@@ -53,7 +56,7 @@ private:
     LIBKAICHATWIDGETS_NO_EXPORT void slotDownloadModelFinished(const QString &modelName);
     LIBKAICHATWIDGETS_NO_EXPORT void slotConfigureNotifications();
     LIBKAICHATWIDGETS_NO_EXPORT void setupStatusBar();
-    LIBKAICHATWIDGETS_NO_EXPORT void slotToolProgressInfoChanged(const QString &str);
+    LIBKAICHATWIDGETS_NO_EXPORT void slotStatusBarInfoChanged(const QString &str);
     bool mReallyClose{false};
     KToggleAction *mShowMenuBarAction = nullptr;
     KHamburgerMenu *mHamburgerMenu = nullptr;
@@ -67,6 +70,6 @@ private:
     KAIChatChangeFontSizeMenu *mChangeFontSizeAction = nullptr;
     QLabel *mToolProgressInfo = nullptr;
 #if defined(Q_OS_WIN) || defined(Q_OS_MACOS)
-    VerifyNewVersionWidgetAction *const mVerifyNewVersionWidgetAction;
+    TextAddonsWidgets::VerifyNewVersionWidget *const mVerifyNewVersionWidget;
 #endif
 };
